@@ -5,6 +5,10 @@ use serde_json::Value;
 use crate::core::db::DriverType;
 use crate::core::Error;
 use crate::sql::rule::SqlRule;
+use crate::crud::CRUDTable;
+use std::ops::Deref;
+use std::collections::HashMap;
+use serde::{Serialize, Deserialize, Serializer, Deserializer};
 
 /// Logic Delete Plugin trait
 pub trait LogicDelete: Send + Sync + Debug {
@@ -13,8 +17,6 @@ pub trait LogicDelete: Send + Sync + Debug {
         std::any::type_name::<Self>()
     }
 
-    fn is_allow(&self, context_id: &str) -> bool;
-
     /// database column
     fn column(&self) -> &str;
     /// deleted data,must be i32
@@ -24,7 +26,6 @@ pub trait LogicDelete: Send + Sync + Debug {
     /// create_remove_sql
     fn create_remove_sql(
         &self,
-        context_id: &str,
         driver_type: &DriverType,
         table_name: &str,
         table_fields: &str,
@@ -33,7 +34,6 @@ pub trait LogicDelete: Send + Sync + Debug {
     /// create_select_sql
     fn create_select_sql(
         &self,
-        context_id: &str,
         driver_type: &DriverType,
         table_name: &str,
         column: &str,
@@ -73,15 +73,6 @@ impl RbatisLogicDeletePlugin {
 }
 
 impl LogicDelete for RbatisLogicDeletePlugin {
-    fn is_allow(&self, context_id: &str) -> bool {
-        for x in &self.excludes {
-            if context_id.starts_with(x) {
-                return false;
-            }
-        }
-        return true;
-    }
-
     fn column(&self) -> &str {
         self.column.as_str()
     }
@@ -96,22 +87,11 @@ impl LogicDelete for RbatisLogicDeletePlugin {
 
     fn create_remove_sql(
         &self,
-        context_id: &str,
         driver_type: &DriverType,
         table_name: &str,
         table_fields: &str,
         sql_where: &str,
     ) -> Result<String, Error> {
-        if !self.is_allow(context_id) {
-            //make delete sql
-            let new_sql = format!(
-                "{} {} {}",
-                crate::sql::TEMPLATE.delete_from.value,
-                table_name,
-                sql_where.trim_start()
-            );
-            return Ok(new_sql);
-        }
         return if table_fields.contains(self.column()) {
             //fields have column
             if sql_where.is_empty() {
@@ -151,21 +131,14 @@ impl LogicDelete for RbatisLogicDeletePlugin {
 
     fn create_select_sql(
         &self,
-        context_id: &str,
         driver_type: &DriverType,
         table_name: &str,
         column: &str,
         table_fields: &str,
         where_sql: &str,
     ) -> Result<String, Error> {
-        let mut where_sql = where_sql.trim().to_string();
+        let where_sql = where_sql.trim().to_string();
         let mut sql = String::new();
-        if self.is_allow(context_id) && table_fields.contains(self.column()) {
-            where_sql = driver_type.make_left_insert_where(
-                &format!("{} = {}", self.column(), self.un_deleted()),
-                &where_sql,
-            );
-        }
         sql = format!(
             "{} {} {} {} {}",
             crate::sql::TEMPLATE.select.value,
@@ -177,3 +150,74 @@ impl LogicDelete for RbatisLogicDeletePlugin {
         Ok(sql)
     }
 }
+
+
+
+/// use this context will not use logic del
+pub struct TableNoLogic<T> where T: CRUDTable {
+    pub table: T,
+}
+
+impl<T> Serialize for TableNoLogic<T> where T: CRUDTable {
+    fn serialize<S>(&self, serializer: S) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error> where
+        S: Serializer {
+        T::serialize(&self.table, serializer)
+    }
+}
+
+impl<'de, T> Deserialize<'de> for TableNoLogic<T> where T: CRUDTable {
+    fn deserialize<D>(deserializer: D) -> Result<Self, <D as Deserializer<'de>>::Error> where
+        D: Deserializer<'de> {
+        let result = T::deserialize(deserializer)?;
+        return Ok(TableNoLogic {
+            table: result,
+        });
+    }
+}
+
+
+impl<T> CRUDTable for TableNoLogic<T> where T: CRUDTable {
+    fn is_use_plugin(plugin_name: &str) -> bool {
+        if plugin_name.eq(std::any::type_name::<RbatisLogicDeletePlugin>()) {
+            return false;
+        }
+        return true;
+    }
+
+    fn table_name() -> String {
+        T::table_name()
+    }
+
+    fn table_columns() -> String {
+        T::table_columns()
+    }
+
+    fn formats(driver_type: &DriverType) -> HashMap<String, fn(arg: &str) -> String> {
+        T::formats(driver_type)
+    }
+
+    fn make_value_sql_arg(
+        &self,
+        db_type: &DriverType,
+        index: &mut usize,
+    ) -> crate::Result<(String, String, Vec<serde_json::Value>)> {
+        T::make_value_sql_arg(&self.table, db_type, index)
+    }
+}
+
+impl<T> Deref for TableNoLogic<T> where T: CRUDTable {
+    type Target = T;
+
+    fn deref(&self) -> &Self::Target {
+        &self.table
+    }
+}
+
+
+impl<T> From<T> for TableNoLogic<T> where T: CRUDTable {
+    fn from(arg: T) -> Self {
+        TableNoLogic {
+            table: arg
+        }
+    }
+}
